<?php

namespace WooCommerce\FedEx;

use WC_Shipping_FedEx;

abstract class Abstract_FedEx_API {

	/**
	 * Endpoint for the API.
	 *
	 * @var string
	 */
	protected $endpoint;
	/**
	 * @var WC_Shipping_FedEx
	 */
	protected $shipping_method;
	/**
	 * @var \WC_Logger|null
	 */
	protected $logger;

	/**
	 * Get the common API request parameters.
	 *
	 * @param string $request_type
	 *
	 * @return array
	 */
	abstract public function get_fedex_api_request( $request_type );

	/**
	 * Prepare request elements.
	 *
	 * @param array $request
	 *
	 * @return array
	 */
	public function prepare_request( $request ) {
		return $request;
	}

	/**
	 * Get result.
	 *
	 * @param array  $request
	 * @param string $request_type
	 *
	 * @return array
	 */
	abstract public function get_result( $request, $request_type );

	/**
	 * Check if Destination Address is Residential.
	 *
	 * @param array $request
	 *
	 * @return bool
	 */
	abstract public function residential_address_validation( $request );

	/**
	 * Process API response.
	 *
	 * @param mixed $result
	 *
	 * @return void
	 */
	abstract public function process_result( $result );

}
